
import React, { useEffect, useRef, useImperativeHandle } from 'react';
import echarts from './echarts';

export default React.forwardRef((props, ref) => {
  const el = useRef()
  const chartRef = useRef()
  const style = {
    width: props.width || '480px',
    height: props.height || '360px',
    ...props.style || {}
  }

  // 向父组件公开 echarts 实例
  useImperativeHandle(ref, () => ({
    chart: chartRef.current,
  }))

  useEffect(() => {
    const chart = echarts.init(el.current)
    chart.setOption(props.option)
    chartRef.current = chart

    return () => chart.dispose()
  }, [props.option])

  useEffect(() => {
    if (chartRef.current) {
      if (props.loading) {
        chartRef.current.showLoading()
      } else {
        chartRef.current.hideLoading()
      }
    }
  }, [props.loading])

  return <div ref={el} style={style}></div>
})
