import React, { useEffect, useState } from 'react';
import { Button, Row, Col, Checkbox, Radio, Input, Space, notification } from 'antd';
// import WangEditor from '@/components/WangEditor';

const RedRequire = () => <i style={{ color: 'red' }}>*</i>

const defaultData = {
  title: undefined,
  question: undefined,
  answerType: 'radio',
  correctAnswers: undefined,
  optionA: undefined,
  optionB: undefined,
  optionC: undefined,
  optionD: undefined,
}

export default (props) => {
  const [formData, setFormData] = useState(defaultData);

  const [correctAnswers, setCorrectAnswers] = useState([])

  const handleFormChange = (field) => (e) => {
    const value = e && e.target ? e.target.value : e;
    setFormData({
      ...formData,
      [field]: value,
    });
  };

  const handleCorrectAnswers = (e) => {
    if (formData.answerType === 'radio' || formData.answerType === 'switch') {
      setCorrectAnswers([e.target.value])
    } else {
      setCorrectAnswers(e && e.length > 0 ? e : [])
    }
  };

  const handleSubmit = () => {
    if (!formData.title) {
      notification.warning({ message: '请填写考题' })
      return
    }
    if (!formData.optionA && !formData.optionB && !formData.optionC && !formData.optionD) {
      notification.warning({ message: '请填写选项' })
      return
    }
    if (!formData.answerType) {
      notification.warning({ message: '请设置题型' })
      return
    }
    if (!formData.correctAnswers) {
      notification.warning({ message: '请设置正确答案' })
      return
    }

    if (props.onSubmit) {
      props.onSubmit(formData)
    }
  };

  const handleCancel = () => {
    if (props.onCancel) {
      props.onCancel();
    }
  };

  const answerTypeDict = Object.keys(props.answerTypeDict).map((key) => ({ value: key, label: props.answerTypeDict[key] }));

  useEffect(() => {
    formData.correctAnswers = (correctAnswers || []).join(',')
  }, [correctAnswers, formData])

  useEffect(() => {
    setFormData(props.value || defaultData)
    if (props.value?.correctAnswers) {
      setCorrectAnswers(props.value.correctAnswers.split(','))
    }
  }, [props.value])

  return (
    <div>
      <Space size="large" direction="vertical" style={{ width: '100%' }}>
        <section>
          <h3><RedRequire />题型:</h3>
          <Radio.Group
            options={answerTypeDict}
            value={formData.answerType}
            onChange={handleFormChange('answerType')}
          />
        </section>

        <section>
          <h3><RedRequire />考题:</h3>
          <Input placeholder="不能超过 300 字" value={formData.title} onChange={handleFormChange('title')} />
        </section>

        {/* <section>
          <h3>详细内容:</h3>
          <WangEditor
            height={120}
            value={formData.question}
            onChange={handleFormChange('question')}
          />
        </section> */}

        <section>
          <h3><RedRequire />选项:</h3>
          <Space size="large" direction="vertical" style={{ width: '100%' }}>
            <Row gutter="24">
              <Col span={12}>
                <Input addonBefore="A" value={formData.optionA} onChange={handleFormChange('optionA')} />
              </Col>
              <Col span={12}>
                <Input addonBefore="B" value={formData.optionB} onChange={handleFormChange('optionB')} />
              </Col>
            </Row>
            {
              formData.answerType !== 'switch' && (
                <Row gutter="24">
                  <Col span={12}>
                    <Input addonBefore="C" value={formData.optionC} onChange={handleFormChange('optionC')} />
                  </Col>
                  <Col span={12}>
                    <Input addonBefore="D" value={formData.optionD} onChange={handleFormChange('optionD')} />
                  </Col>
                </Row>
              )
            }
          </Space>
        </section>

        <section>
          <h3><RedRequire />正确答案:</h3>
          {formData.answerType === 'switch' && (
            <Radio.Group value={correctAnswers[0]} onChange={handleCorrectAnswers} style={{ width: '100%' }}>
              <Row gutter="12">
                <Col span={6}>
                  <Radio value="A">是</Radio>
                </Col>
                <Col span={6}>
                  <Radio value="B">否</Radio>
                </Col>
              </Row>
            </Radio.Group>
          )}
          {formData.answerType === 'radio' && (
            <Radio.Group value={correctAnswers[0]} onChange={handleCorrectAnswers} style={{ width: '100%' }}>
              <Row gutter="12">
                <Col span={6}>
                  <Radio value="A">A</Radio>
                </Col>
                <Col span={6}>
                  <Radio value="B">B</Radio>
                </Col>
                <Col span={6}>
                  <Radio value="C">C</Radio>
                </Col>
                <Col span={6}>
                  <Radio value="D">D</Radio>
                </Col>
              </Row>
            </Radio.Group>
          )}
          {formData.answerType === 'checkbox' && (
            <Checkbox.Group value={correctAnswers} onChange={handleCorrectAnswers} style={{ width: '100%' }}>
              <Row gutter="12">
                <Col span={6}>
                  <Checkbox value="A">A</Checkbox>
                </Col>
                <Col span={6}>
                  <Checkbox value="B">B</Checkbox>
                </Col>
                <Col span={6}>
                  <Checkbox value="C">C</Checkbox>
                </Col>
                <Col span={6}>
                  <Checkbox value="D">D</Checkbox>
                </Col>
              </Row>
            </Checkbox.Group>
          )}
        </section>

        <section>
          <Row gutter="24">
            <Col span={4}>
              <Button type="primary" onClick={handleSubmit}>
                确定
              </Button>
            </Col>
            <Col span={4}>
              <Button type="default" onClick={handleCancel}>
                取消
              </Button>
            </Col>
          </Row>
        </section>
      </Space>
    </div>
  );
};
