import React, { useEffect, useState } from 'react';
import { connect, history } from 'umi';
import { PageContainer } from '@ant-design/pro-layout';
import Container from '@/components/Container';
import request from '@/utils/request';

import ProForm, { ProFormSelect, ProFormText } from '@ant-design/pro-form';
import UploadImage from '@/components/UploadImage';
import { notification, Form, Button } from 'antd';

const HotEdit = (props) => {
  const { id } = props.location.query;
  const [loading, setLoading] = useState(false);
  const [form] = Form.useForm();
  //   const [bannerData, setBannerData] = useState({});

  useEffect(() => {
    if (id) {
      setLoading(true);
      request(`/topic/${id}`)
        .then((res) => {
          form.setFieldsValue(res);
          //   setBannerData(res);
          //   set
          setLoading(false);
        })
        .catch((e) => {
          setLoading(false);
          notification.error({ message: e.message });
        });
    }
  }, [form, id]);

  const handleSubmit = (values) => {

    if (!id) {
      setLoading(true);
      return request('/topic', { method: 'post', data: values })
        .then(() => {
          // props.onChange(res)
          // form.setFieldsValue(res)
          notification.info({ message: '添加成功' });
          setLoading(false);
          history.go('-1');
        })
        .catch((e) => {
          notification.error({ message: e.message });
          setLoading(false);
          return Promise.reject(e.message);
        });
    }
    setLoading(true);
    return request(`/topic/${id}`, { method: 'put', data: { serialNo: id, ...values } })
      .then(() => {
        // props.onChange(res)
        // form.setFieldsValue(res)
        notification.info({ message: '修改成功' });
        setLoading(false);
        history.go('-1');
      })
      .catch((e) => {
        notification.error({ message: e.message });
        setLoading(false);
        return Promise.reject(e.message);
      });
  };

  return (
    <PageContainer
      header={{
        extra: [
          <Button key="1" onClick={() => history.go('-1')}>
            返回
          </Button>,
        ],
      }}
    >
      <Container loading={loading}>
        <ProForm form={form} onFinish={handleSubmit}>
          <ProFormText
            label="标题"
            placeholder="输入标题"
            name="targetTitle"
            rules={[{ required: true, message: '请填写标题' }]}
          />

          <Form.Item
            name="poster"
            label="图片"
            placeholder="请选择图片"
            extra="支持jpg/png文件，且不超过500kb"
            rules={[{ required: true, message: '请上传图片' }]}
          >
            <UploadImage />
          </Form.Item>

          <ProFormSelect
            label="类型"
            placeholder="请选择类型"
            initialValue={'post'}
            name="targetType"
            options={[
              {
                value: 'post',
                label: '科普',
              },
            ]}
            rules={[{ required: true, message: '请选择板块' }]}
          />

          <ProFormSelect
            label="科普知识"
            placeholder="请选择科普知识"
            name="targetId"
            showSearch
            request={async ({ keyWords }) => {
              // if (keyWords) {
              return request('/post', {
                method: 'get',
                params: { name: keyWords, pageNum: 1, pageSize: 1000 },
              })
                .then((res) => {
                  return res?.records?.map((x) => {
                    return { label: x.name, value: x.postId };
                  });
                })
                .catch((e) => {
                  notification.error({ message: e.message });
                  return Promise.reject(e.message);
                });
              // }
            }}
          />
        </ProForm>
      </Container>
    </PageContainer>
  );
};

export default connect(() => ({}))(HotEdit);
