import React, { useEffect, useState } from 'react';
import { connect, history } from 'umi';

import { PageContainer } from '@ant-design/pro-layout';
import Container from '@/components/Container';
import { Input, Form, Button, notification, Upload, message } from 'antd';
import ProForm, {
  ProFormText,
  ProFormTextArea,
  ProFormSelect,
  ProFormDependency,
} from '@ant-design/pro-form';
import request from '@/utils/request';
import School from '@/components/School';
import UploadImage from '@/components/UploadImage';
import { UploadOutlined } from '@ant-design/icons';
import uploadFile from '@/utils/uploadFile';

const { Search } = Input;
const TestEdit = (props) => {
  const { id, schoolId } = props.location.query;

  const [searchLoading, setSearchLoading] = useState(false);
  const [school, setSchool] = useState();
  const [fileList, setFileList] = useState([]);

  const [searchValue, setSearchValue] = useState();

  const [form] = Form.useForm();

  // eslint-disable-next-line no-shadow
  const getData = (id) => {
    if (id) {
      request(`/student-no/${id}`, { params: { schoolId: school } })
        .then((res) => {
          form.setFieldsValue(res);
          setSearchLoading(false);
        })
        .catch((e) => {
          setSearchLoading(false);
          notification.error({ message: '未找到该学生' });
          form.resetFields();
        });
    } else {
      // this.setState({ data: [] });
    }
  };

  useEffect(() => {
    if (id) {
      if (id) {
        request(`/medical-log/${id}`)
          .then((res) => {
            form.setFieldsValue({ ...res });
            setSearchLoading(false);
          })
          .catch((e) => {
            setSearchLoading(false);
          });
      } else {
        // this.setState({ data: [] });
      }
    }
  }, [id]);

  const onSearch = (value) => {
    if (value) {
      getData(value);
      setSearchLoading(true);
    } else {
      // this.setState({ data: [] });
    }
  };

  const addTestLog = async (value) => {
    await request('/taTestLog', { method: 'post', data: value })
      .then(() => {
        // notification.success({ message: '新建成功' });
        // history.go('-1');
      })
      .catch((e) => {
        notification.error({ message: e.message });
      });
  };

  const handleSubmit = async (value) => {
    console.log(value);
    const { studentId, attchment } = value;
    if (!studentId) {
      message.error(`请选择学生`);
    }
    try {
      if (attchment && attchment.fileList.length > 0) {
        attchment.fileList.map((x) => {
          addTestLog({ studentId, name: x.name, attchment: x.response });
          return null;
        });
        notification.success({ message: '新建成功' });
        history.go('-1');
      }
    } catch (error) {
      notification.error({ message: '创建失败' });
    }
  };

  const handleSchoolChange = (value) => {
    setSchool(value);
    setSearchValue('');
    form.resetFields();
  };

  return (
    <PageContainer
      header={{
        extra: [
          <Button key="1" onClick={() => history.go('-1')}>
            返回
          </Button>,
        ],
      }}
    >
      <Container>
        <ProForm form={form} submitter={!id} onFinish={handleSubmit}>
          {!id && (
            <ProForm.Group layout="inline">
              <School
                value={school}
                onChange={handleSchoolChange}
                style={{ width: 200, marginBottom: '20px' }}
                allowClear
              />
              <Search
                placeholder="请输入学号"
                value={searchValue}
                onChange={(e) => setSearchValue(e.value)}
                loading={searchLoading}
                style={{ width: 200, marginBottom: '20px' }}
                onSearch={onSearch}
              />
            </ProForm.Group>
          )}
          <Form.Item name="studentId" noStyle />

          <ProForm.Group layout="inline" title="就诊信息">
            <ProFormText
              label="姓名"
              placeholder="输入名称"
              name="name"
              fieldProps={{ bordered: false, readOnly: true }}
              // rules={[{ required: true, message: '请填写名称' }]}
            />
            <ProFormSelect
              options={[
                {
                  value: 1,
                  label: '男',
                },
                {
                  value: 2,
                  label: '女',
                },
              ]}
              name="sex"
              label="性别"
              fieldProps={{ bordered: false, open: false, allowClear: false }}
              // rules={[{ required: true, message: '请选择性别' }]}
            />
            <ProFormText
              label="学号"
              placeholder="输入学号"
              name="studentNo"
              fieldProps={{ bordered: false, readOnly: true }}
              // rules={[{ required: true, message: '请填写学号' }]}
            />
            <ProFormText
              label="联系方式"
              placeholder="输入联系方式"
              name="phone"
              fieldProps={{ bordered: false, readOnly: true }}
              // rules={[{ required: true, message: '请填写联系方式' }]}
            />
          </ProForm.Group>

          <Form.Item
            name="attchment"
            label="体检报告"
            placeholder="请选择体检报告"
            // valuePropName="fileList"
            rules={[{ required: true, message: '请上传体检报告' }]}
          >
            <Upload
              accept=".pdf"
              // listType="picture-card"
              // className="avatar-uploader"
              // showUploadList={false}
              // fileList={fileList}
              customRequest={uploadFile}
              onChange={(info) => {
                if (info.file.status !== 'uploading') {
                  console.log(info.file, info.fileList);
                }
                if (info.file.status === 'done') {
                  message.success(`${info.file.name} 上传成功`);
                  // setFileList([info.file])
                } else if (info.file.status === 'error') {
                  message.error(`${info.file.name} 上传失败`);
                }
              }}
            >
              <Button icon={<UploadOutlined />}>点击上传</Button>
            </Upload>
    
          </Form.Item>

        </ProForm>
      </Container>
    
    </PageContainer>
  );
};

export default TestEdit;
