import React, { useState, useRef, useCallback } from 'react';
import { connect, history } from 'umi';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import { PlusOutlined } from '@ant-design/icons';
import { Button,  Space,Image } from 'antd';
import  { queryTable } from '@/utils/request';
import School from '@/components/School';
import Specialty from '@/components/Specialty';

const VisitList = () => {

  const [school, setSchool] = useState({});
  const [abc, setA] = useState();
  
  const ref = useRef();
  const handleMedicalClick = useCallback((id) => {
    history.push(id ? `/medical/Test/edit?id=${id}&schoolId=${school?.schoolId}` : `/medical/Test/edit?schoolId=${school?.schoolId}`);
  }, []);

  const actions = [   
    <Button key="button" icon={<PlusOutlined />} type="primary" onClick={() => handleMedicalClick()}>
      新建
    </Button>,
  ];

  
  const renderFormItem = (item, config, form) => {
    const handleSchoolChange = (schoolId, schoolInfo) => {
      form.setFieldsValue({ schoolId });
      form.submit();
      console.log(schoolInfo, 'schoolInfo');
      setSchool({ ...schoolInfo });
    };

    return <School onChange={handleSchoolChange} allowClear />;
  };

  const columns = [
    {
      title: '编号',
      dataIndex: 'serialNo',
      hideInSearch: true,

      align: 'center',
    },
    {
      title: '学校',
      dataIndex: 'schoolId',
      align: 'center',
      render: (_, row) => row.schoolName||"-",
      renderFormItem: (item, config, form) => (
        <School
          autoDefault={false}
          onChange={(schoolId) => {form.resetFields(['specialtyId']);form.setFieldsValue({ schoolId });}}
          allowClear
        ></School>
      ),
    },
   

    {
      title: '学号',
      dataIndex: 'studentNo',
      align: 'center',
     
    },
    {
      title: '姓名',
      dataIndex: 'name',
      align: 'center',
      hideInSearch: true,
      // hideInTable: true,
    },
    {
      title: '性别',
      dataIndex: 'status',
      align: 'center',
      hideInSearch: true,
      valueEnum: {
        1: { text: '男' },
        2: { text: '女' },
      },
    },
    {
      title: '专业',
      dataIndex: 'specialtyId',
      align: 'center',
      render: (_, row) => row.specialtyName||'-',
      renderFormItem: (item, config, form) => {
        const schoolId = form.getFieldValue('schoolId');
        return <Specialty schoolid={schoolId} disabled={!schoolId}></Specialty>;
      },
    },
    {
      title: '创建时间',
      dataIndex: 'createDate',
      align: 'center',
      hideInSearch: true,
      valueType: 'dateTime',
    },
    
    {
      title: '操作',
      dataIndex: 'action',
      align: 'center',
      hideInSearch: true,
      render: (text, record) => (
        <Space size="middle">
          <a href={record.attchment} target="_blank" rel="noreferrer">查看报告</a>
          {/* <a onClick={()=>setA(record.attchment)}>查看报告</a> */}
        </Space>
      ),
    },
  ];

  return (
    <PageContainer>
      <ProTable
        columns={columns}
        params={{}}
        request={queryTable('/testLog')}
        formRef={ref}
        rowKey="serialNo"
        headerTitle="体检列表"
        search={{
          labelWidth: '4em',
        }}
        toolBarRender={() => actions}
      />
     
   
    </PageContainer>
  );
};

export default connect((s) => ({
  typeList: s.post.typeList,
}))(VisitList);
