import React, { useEffect, useMemo, useRef, useState } from 'react';
import { connect, history } from 'umi';
import {Space, Button} from 'antd'
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import request, { queryTable } from '@/utils/request';

const StudentData = (props) => {
  const { postId } = props.location.query;

  const tableRef = useRef()
  const [schoolDict, setSchoolDict] = useState({})
  

  const toSave =(row)=>{

    if(row.savedNum>0){
      history.push(`/report/student/savenum?schoolId=${row?.schoolId}&personId=${row.personId}`);
     
      
    }

  }

  const toReade =(row)=>{

    if(row.readedNum>0){
      history.push(`/report/student/readednum?schoolId=${row?.schoolId}&personId=${row.personId}`);
    }

  }
  const toPoint =(row)=>{

    if(row.pointNum>0){
      history.push(`/report/student/pointnum?schoolId=${row?.schoolId}&personId=${row.personId}`);
    }

  }
  
  const columns = useMemo(() => [
    {
      title: '排名',
      key: 'topN',
      hideInSearch: true,
      render: (_, $, index) => index + 1,
    },
    {
      title: '学校',
      key: 'schoolId',
      dataIndex: 'schoolId',
      valueType: 'select',
      valueEnum: schoolDict,
    },
    {
      title: '名称',
      key: 'name',
      dataIndex: 'name',
    },
    {
      title: '手机号',
      key: 'phone',
      dataIndex: 'phone',
      hideInSearch: true,
    },
    {
      title: '收藏文章数',
      key: 'savedNum',
      dataIndex: 'savedNum',
      hideInSearch: true,
      sorter: true,
      render: (text, row) => (
        <Space size="middle">
          {text?<a onClick={() => toSave(row)}>{text}</a>:0}
        </Space>
      ),
    },
    {
      title: '阅读文章数',
      key: 'readedNum',
      dataIndex: 'readedNum',
      hideInSearch: true,
      sorter: true,
      render: (text, row) => (
        <Space size="middle">
          {text?<a onClick={() => toReade(row)}>{text}</a>:0}
        </Space>
      ),
    },
    {
      title: '总积分',
      key: 'pointNum',
      dataIndex: 'pointNum',
      hideInSearch: true,
      sorter: true,
      render: (text, row) => (
        <Space size="middle">
          {text?<a onClick={() => toPoint(row)}>{text}</a>:0}
        </Space>
      ),
    },
    {
      title: '学分',
      key: 'creditNum',
      dataIndex: 'creditNum',
      hideInSearch: true,
      sorter: true,
    },
  ], [schoolDict])

  useEffect(() => {
    request('/school', { params: { pageSize: 500 } }).then(res => {
      const records = res.records || []
      const dict = records.reduce((acc, item) => {
        return {
          ...acc,
          [item.schoolId]: { text: item.name },
        };
      }, {})
      setSchoolDict(dict)
    }).catch((e) => {
      // eslint-disable-next-line
      console.error(e.message)
    })

  // eslint-disable-next-line
  }, [])

  return (
    <PageContainer
    header={{
      extra: [
        postId&&<Button key="1" onClick={() => history.go('-1')}>
          返回
        </Button>,
      ],
    }}>
      <ProTable
        actionRef={tableRef}
        columns={columns}
        params={{postId}}
        request={queryTable('/statis/student-data')}
        rowKey="personId"
        search={{
          labelWidth: '4em',
          defaultCollapsed: false,
          optionRender: (searchConfig, formProps, dom) => [
            ...dom.reverse(),
            <Button key="out"  type="primary">导出</Button>,
          ],
        }}
       
        options={false}
      />
    </PageContainer>
  );
};

export default connect((s) => ({
  user: s.user.currentUser,
}))(StudentData);
