import React, { useEffect, useState } from 'react';
import { history } from 'umi';
import { PageContainer } from '@ant-design/pro-layout';
import Container from '@/components/Container';
import request from '@/utils/request';
import { notification, Card, Descriptions, Divider, Image, Button } from 'antd';

const StudentEdit = (props) => {
  const { id } = props.location.query;
  const [loading, setLoading] = useState(false);
  const [data, setData] = useState({});

  useEffect(() => {
    if (id) {
      setLoading(true);
      request(`/student/${id}`)
        .then((res) => {
          setData(res);
          setLoading(false);
        })
        .catch((e) => {
          setLoading(false);
          notification.error({ message: e.message });
        });
    }
  }, [id]);

  return (
    <PageContainer
      header={{
        extra: [
          <Button key="1" onClick={() => history.go('-1')}>
            返回
          </Button>,
        ],
      }}
    >
      <Container loading={loading}>
        <Card bordered={false}>
          <div style={{ display: 'flex' }}>
            <div style={{ marginRight: 40 }}>
              {/* <Avatar src={data.avatar} size="large" /> */}
              <Image src={data.avatar} preview={false} width={120}></Image>
            </div>

            <Descriptions title="学生信息" style={{ marginBottom: 32 }}>
              <Descriptions.Item label="姓名">{data.name}</Descriptions.Item>
              <Descriptions.Item label="性别">
                {data.sex === 1 ? '男' : (data.sex === 2  ?'女':'未知')}
              </Descriptions.Item>
              <Descriptions.Item label="积分">{data.personData?.pointNum}</Descriptions.Item>
              <Descriptions.Item label="联系方式">{data.phone}</Descriptions.Item>
              <Descriptions.Item label="邮箱">{data.email}</Descriptions.Item>
            </Descriptions>
          </div>

          <Divider style={{ marginBottom: 32 }} />
          <Descriptions title="学校信息" style={{ marginBottom: 32 }}>
            <Descriptions.Item label="学校">{data.schoolName}</Descriptions.Item>
            <Descriptions.Item label="专业">{data.specialtyName}</Descriptions.Item>
            <Descriptions.Item label="学界">{data.schoolBatch}</Descriptions.Item>
            <Descriptions.Item label="学号">{data.studentNo}</Descriptions.Item>
          </Descriptions>
        </Card>
      </Container>
    </PageContainer>
  );
};

export default StudentEdit;
